==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeDataProxyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Data proxy properties for a managed dedicated integration runtime.
 * @property connectVia The self-hosted integration runtime reference.
 * @property path The path to contain the staged data in the Blob storage.
 * @property stagingLinkedService The staging linked service reference.
 */
public data class IntegrationRuntimeDataProxyPropertiesArgs(
    public val connectVia: Output<EntityReferenceArgs>? = null,
    public val path: Output<String>? = null,
    public val stagingLinkedService: Output<EntityReferenceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs.builder()
            .connectVia(connectVia?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .path(path?.applyValue({ args0 -> args0 }))
            .stagingLinkedService(
                stagingLinkedService?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeDataProxyPropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeDataProxyPropertiesArgsBuilder internal constructor() {
    private var connectVia: Output<EntityReferenceArgs>? = null

    private var path: Output<String>? = null

    private var stagingLinkedService: Output<EntityReferenceArgs>? = null

    /**
     * @param value The self-hosted integration runtime reference.
     */
    @JvmName("jisrdhnvctnhecyn")
    public suspend fun connectVia(`value`: Output<EntityReferenceArgs>) {
        this.connectVia = value
    }

    /**
     * @param value The path to contain the staged data in the Blob storage.
     */
    @JvmName("juktbghethqijjuk")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The staging linked service reference.
     */
    @JvmName("kcdqrlkukvqshrix")
    public suspend fun stagingLinkedService(`value`: Output<EntityReferenceArgs>) {
        this.stagingLinkedService = value
    }

    /**
     * @param value The self-hosted integration runtime reference.
     */
    @JvmName("egmqgypqxxwddcnq")
    public suspend fun connectVia(`value`: EntityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectVia = mapped
    }

    /**
     * @param argument The self-hosted integration runtime reference.
     */
    @JvmName("vvyjmgpibsqkjcyw")
    public suspend fun connectVia(argument: suspend EntityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = EntityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.connectVia = mapped
    }

    /**
     * @param value The path to contain the staged data in the Blob storage.
     */
    @JvmName("vcjbwumdcolbyiwj")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value The staging linked service reference.
     */
    @JvmName("rtqwquhwtpqwgcnx")
    public suspend fun stagingLinkedService(`value`: EntityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stagingLinkedService = mapped
    }

    /**
     * @param argument The staging linked service reference.
     */
    @JvmName("evavxddhqarmwlmx")
    public suspend fun stagingLinkedService(argument: suspend EntityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = EntityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.stagingLinkedService = mapped
    }

    internal fun build(): IntegrationRuntimeDataProxyPropertiesArgs =
        IntegrationRuntimeDataProxyPropertiesArgs(
            connectVia = connectVia,
            path = path,
            stagingLinkedService = stagingLinkedService,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/IntegrationRuntimeDataProxyPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Data proxy properties for a managed dedicated integration runtime.
 * @property connectVia The self-hosted integration runtime reference.
 * @property path The path to contain the staged data in the Blob storage.
 * @property stagingLinkedService The staging linked service reference.
 */
public data class IntegrationRuntimeDataProxyPropertiesArgs(
    public val connectVia: Output<EntityReferenceArgs>? = null,
    public val path: Output<String>? = null,
    public val stagingLinkedService: Output<EntityReferenceArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs =
        com.pulumi.azurenative.datafactory.inputs.IntegrationRuntimeDataProxyPropertiesArgs.builder()
            .connectVia(connectVia?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .path(path?.applyValue({ args0 -> args0 }))
            .stagingLinkedService(
                stagingLinkedService?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [IntegrationRuntimeDataProxyPropertiesArgs].
 */
@PulumiTagMarker
public class IntegrationRuntimeDataProxyPropertiesArgsBuilder internal constructor() {
    private var connectVia: Output<EntityReferenceArgs>? = null

    private var path: Output<String>? = null

    private var stagingLinkedService: Output<EntityReferenceArgs>? = null

    /**
     * @param value The self-hosted integration runtime reference.
     */
    @JvmName("nnssbhnaobqcprpi")
    public suspend fun connectVia(`value`: Output<EntityReferenceArgs>) {
        this.connectVia = value
    }

    /**
     * @param value The path to contain the staged data in the Blob storage.
     */
    @JvmName("dkcthoigtivbhfgy")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The staging linked service reference.
     */
    @JvmName("thvmcqejjjbuxuqe")
    public suspend fun stagingLinkedService(`value`: Output<EntityReferenceArgs>) {
        this.stagingLinkedService = value
    }

    /**
     * @param value The self-hosted integration runtime reference.
     */
    @JvmName("ycfvboawqnrsknqt")
    public suspend fun connectVia(`value`: EntityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.connectVia = mapped
    }

    /**
     * @param argument The self-hosted integration runtime reference.
     */
    @JvmName("ppsbadpjhyesyskj")
    public suspend fun connectVia(argument: suspend EntityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = EntityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.connectVia = mapped
    }

    /**
     * @param value The path to contain the staged data in the Blob storage.
     */
    @JvmName("dqvnaygqqapnrpuu")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    /**
     * @param value The staging linked service reference.
     */
    @JvmName("gbpqwmnoqrjwmamq")
    public suspend fun stagingLinkedService(`value`: EntityReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.stagingLinkedService = mapped
    }

    /**
     * @param argument The staging linked service reference.
     */
    @JvmName("cljaysyvnlregtdj")
    public suspend fun stagingLinkedService(argument: suspend EntityReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = EntityReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.stagingLinkedService = mapped
    }

    internal fun build(): IntegrationRuntimeDataProxyPropertiesArgs =
        IntegrationRuntimeDataProxyPropertiesArgs(
            connectVia = connectVia,
            path = path,
            stagingLinkedService = stagingLinkedService,
        )
}
